@@ -1,4 +1,3 @@
-context("ggdag_drelationship")
 set.seed(1234)
 
 test_that("d relationships correctly identified", {
@@ -9,7 +8,7 @@ test_that("d relationships correctly identified", {
   p3 <- ggdag_drelationship(test_dag, "x", "y", controlling_for = "m", collider_lines = FALSE)
   expect_doppelganger("ggdag_drelationship() d-separates x and y", p1)
   expect_doppelganger("ggdag_drelationship() d-connects x and y", p2 + theme_test() + theme(legend.position = "none"))
-  expect_doppelganger("ggdag_drelationship() d-connects x and y: no collider line", p3)
+  expect_doppelganger("ggdag_drelationship() d-connects xy: no collider", p3)
 
   p4 <- ggdag_dseparated(test_dag, "x", "y")
   p5 <- ggdag_dconnected(test_dag, "x", "y")
